![](https://camo.githubusercontent.com/30a50b0142b709751620b6a52935bb8b31b8119830301b330f873b988945cc86/68747470733a2f2f6d69726f2e6d656469756d2e636f6d2f6d61782f313030302f312a70676b7a6e72752d3833396c3654746d397a617671512e706e67)

# Ackee Frontend Tookit
> Set of tools, libraries and all stuff useful for frontend development in Ackee having DRY in mind.

There is live [showroom (Storybook)](https://frontend-toolkit.ack.ee/) for some components/tools.

## How to use

1. Install
Run
`yarn add ackee-frontend-toolkit`
or
`npm install ackee-frontend-toolkit`.
2. Import
Depending on your prefered module managment system, you can use directory `ackee-frontend-toolkit/lib` (CommonJS) or `ackee-frontend-toolkit/es` (ES2015) to import things you need.


You can choose one of three ways for importing:
```js
// 1. Import partially
import loadable from 'ackee-frontend-toolkit/HOC/loadable';

loadable(...)

// 2. Import from namespace
import * HOC from 'ackee-frontend-toolkit/HOC';

HOC.loadable(...)

// 3. Import from full package
import * ackee from 'ackee-frontend-toolkit';

ackee.loadable(...)
 ```

## How to develop

`yarn build` or `npm run build` make sources prepared to use.

## What's inside

### Components

* [DataList](./docs/components/dataList.md)

### High order components
 * [loadable](./docs/HOC/loadable.md)
 * [makeDropzone](./docs/HOC/makeDropzone.md)
 * authorizable
 * [errorBoundary](./docs/HOC/errorBoundary.md)
 * [pure](./docs/HOC/pure.md)

### Helpers
 * [auth helpers](./docs/helpers/auth.md)
 * [action types helper](./docs/helpers/actionTypes.md)
 * [component name helper](./docs/helpers/componentName.md)
 * testing helpers

### Sagas
 * [routing](./docs/sagas/routing.md)
 * [formSubmit](./docs/sagas/form.md)
 * [error](./docs/sagas/error.md)
 * [combineDependencies helper](./docs/sagas/combineDependenciesHandlers.md)

### Actions
* [form](./docs/actions/formActions.md)
* [logging](./docs/actions/loggingActions.md)

### [Selectors](./docs/selectors/index.md)

### Modules

* [chat](./src/modules/chat/README.md)
* [localization](./src/modules/localization/README.md)
* [routing-history](./src/modules/routing-history/README.md)

## What we use

We don't want to invent a wheel every day so we are trying to use as much vendor components, utilities and helpers as possible. We remarked [the approved ones](./docs/vendors.md) to don't let us forget them :)

## Development recipes

* [Using form saga](./docs/recipes/usingFormSaga.md)
* [Lazy loading](./docs/recipes/lazyLoading.md)
