# `errorBoundary(ErrorComponent): BoundedComponent`

High order component for setting error boundaries up. Implementation is very similar to that [described by React authors](https://reactjs.org/docs/error-boundaries.html).

> ![Important](../alert-icon.png "Improtant note")
 You need React >= v16 and Redux in your app to make everything working properly

### Arguments
1. `ErrorComponent`: React component that shows the error. Receives
  1. prop `error` which is occured error
  2. all the props supplied to `BoundedComponent`

### Returns
Component that catch any unexpected error that occured anywhere in subtree and invoke [`LOG_ERROR`]() action

### Examples

```jsx
import errorBoundary from 'ackee-frontend-toolkit/lib/HOC/errorBoundary';

const SimpleErrorComponent = ({ error }) => (
    <div>
        Error occured!:
        <code>{error.message}</code>
    </div>
);

errorBoundary(SimpleErrorComponent)(
    <div>
        <p>Error will be caught up</p>
        <button onClick={(e) => e.callNonExistingFunction()}>Do error</button>
    </div>
);
```
