# `loadable(LoaderComponent: React.Component, defaultText?: string): (MyComponent) => LoadableMyComponent`

High order component that wraps your content component with supplied loader and pass prop `showLoader`
just to the loader.

HOC accepts two arguments:

* `LoaderComponent` - component that is used as a loader, so it's displayed while `showLoader` is truthy
* `defaultText` [optional] - default text that is provided to `LoaderComponent` unless `loaderText` prop is supplied to LoadableComponent

Wrapped loadable component accepts two more props:
* `showLoader` - controls if loader is visible
* `loaderText` [optional] - text that is provided into `LoaderComponent`

`LoaderComponent` receives loadable content (the component(s) hidden behind loader until load finish) as a children and two props:
* `show` - loader visibility flag
* `text` - loader text

### Example

```jsx
// components/Loader.jsx
const Loader = ({ children, show, text }) => (
    <div>
        { children }
        { show && <div className="loader">{text}</div> }
    </div>
);

export default Loader;
```

```jsx
// containers/Users.js
import loadable from 'ackee-frontend-toolkit/lib/HOC/loadable';
import Users from '../components/Users';
import Loader from '../components/Loader';

export default compose(
    connect(
        state => ({
            showLoader: isFetchingUsersSelector(state),
        })
    )
    loadable(SimpleLoader),
)(Users);
```

```jsx
// components/App.js
import Users from '../containers/Users';

const App = () => (
    <Users />
);

export default App;
```

