import { React, PropTypes, classnames, FormattedMessage, DataList, pure } from '../../dependencies';

import SearchForm from '../../containers/SearchForm';
import ListConversationsItem from './ConversationsItem';

var Conversations = function Conversations(_ref) {
    var userId = _ref.userId,
        conversations = _ref.conversations,
        isLoaded = _ref.isLoaded,
        loader = _ref.loader,
        visible = _ref.visible,
        searchEnabled = _ref.searchEnabled,
        searchLabel = _ref.searchLabel,
        ConversationsItem = _ref.ConversationsItem,
        noDataMessage = _ref.noDataMessage;
    return React.createElement(
        'div',
        {
            className: classnames('conversations', {
                'conversations--hidden': !visible
            })
        },
        searchEnabled && React.createElement(SearchForm, { searchLabel: searchLabel }),
        !isLoaded ? loader : React.createElement(DataList, {
            data: conversations,
            RowComponent: React.createElement(ListConversationsItem, { userId: userId, ContentComponent: ConversationsItem }),
            noDataMessage: noDataMessage,
            element: 'ul'
        })
    );
};

Conversations.propTypes = {
    userId: PropTypes.string.isRequired,
    ConversationsItem: PropTypes.func.isRequired,
    conversations: PropTypes.arrayOf(PropTypes.shape({})),
    isLoaded: PropTypes.bool.isRequired,
    visible: PropTypes.bool,
    searchEnabled: PropTypes.bool,
    searchLabel: PropTypes.node,
    loader: PropTypes.node,
    noDataMessage: PropTypes.node
};

Conversations.defaultProps = {
    conversations: [],
    visible: true,
    searchEnabled: false,
    searchLabel: null,
    loader: React.createElement(FormattedMessage, { id: 'chat.conversations.loading' }),
    noDataMessage: React.createElement(FormattedMessage, { id: 'chat.conversations.noData' })
};

export default pure()(Conversations);