import 'babel-polyfill';
import React from 'react';
import { Provider } from 'react-redux';
import { IntlProvider } from 'react-intl';

import { storiesOf } from '@storybook/react';

import DataLoadDelay from './DataLoadDelay';
import { Conversation } from '../';

import { intlMessages } from './chatData';

import { store } from './chat.envSetup';

import './chatStories.scss';
import '../styles.scss';

storiesOf('Modules|chat/Conversation', module).addDecorator(function (story) {
    return React.createElement(
        Provider,
        { store: store },
        React.createElement(
            IntlProvider,
            { locale: 'en', messages: intlMessages },
            React.createElement(
                'div',
                { className: 'panel messages-panel' },
                story()
            )
        )
    );
}).add('basic', function () {
    return React.createElement(Conversation, {
        conversationId: 'driver_1551',
        userId: 'dispatcher_9',
        sendLabel: 'Send it!'
    });
}).add('default loader', function () {
    return React.createElement(
        DataLoadDelay,
        {
            store: store,
            firebaseDataPath: 'messages/driver_1551',
            delay: 5000
        },
        React.createElement(Conversation, {
            conversationId: 'driver_1551',
            userId: 'dispatcher_9',
            sendLabel: 'Send it!'
        })
    );
}).add('custom loader', function () {
    return React.createElement(
        DataLoadDelay,
        {
            store: store,
            firebaseDataPath: 'messages/driver_1551'
        },
        React.createElement(Conversation, {
            conversationId: 'driver_1551',
            userId: 'dispatcher_9',
            sendLabel: 'Send it!',
            loader: React.createElement(
                'h1',
                { style: { textAlign: 'center' } },
                'Loading whole conversation'
            )
        })
    );
});