import 'babel-polyfill';
import React from 'react';
import PropTypes from 'prop-types';
import { Provider } from 'react-redux';
import { IntlProvider } from 'react-intl';
import classnames from 'classnames';
import _ from 'lodash';

import { storiesOf } from '@storybook/react';

import DataLoadDelay from './DataLoadDelay';
import { Messages } from '../';

import { intlMessages } from './chatData';

import { store } from './chat.envSetup';

import './chatStories.scss';
import '../styles.scss';

var Author = function Author(_ref) {
    var author = _ref.author,
        seen = _ref.seen;
    return React.createElement(
        'div',
        { className: classnames('author-circle', { 'author--unseen': !seen }) },
        _.get(author, 'name', '').split(' ').map(function (s) {
            return s.charAt(0);
        }).join('')
    );
};

Author.propTypes = {
    author: PropTypes.shape({
        name: PropTypes.string.isRequired
    }).isRequired,
    seen: PropTypes.bool.isRequired
};

var Message = function Message(_ref2) {
    var text = _ref2.text,
        time = _ref2.time,
        seen = _ref2.seen,
        amIAuthor = _ref2.amIAuthor,
        author = _ref2.author;
    return React.createElement(
        'div',
        { style: { opacity: seen ? 0.5 : 1 }, className: 'custom-message' },
        React.createElement(
            'h4',
            null,
            ' ',
            amIAuthor ? 'ME' : _.get(author, 'name')
        ),
        React.createElement(
            'em',
            null,
            new Date(time).toString()
        ),
        React.createElement(
            'p',
            null,
            text
        )
    );
};

/* eslint-disable react/require-default-props,react/no-unused-prop-types */
Message.propTypes = {
    author: PropTypes.shape({
        authorId: PropTypes.string.isRequired,
        name: PropTypes.string
    }),
    image: PropTypes.string,
    text: PropTypes.string,
    time: PropTypes.number.isRequired,
    seen: PropTypes.bool.isRequired,
    amIAuthor: PropTypes.bool.isRequired,

    MessageAuthor: PropTypes.func,
    MessageImage: PropTypes.func,
    dateFormat: PropTypes.string
};
/* eslint-enable react/require-default-props,react/no-unused-prop-types */

storiesOf('Modules|chat/Messages', module).addDecorator(function (story) {
    return React.createElement(
        Provider,
        { store: store },
        React.createElement(
            IntlProvider,
            { locale: 'en', messages: intlMessages },
            React.createElement(
                'div',
                { className: 'panel messages-panel' },
                story()
            )
        )
    );
}).add('basic', function () {
    return React.createElement(Messages, { conversationId: 'driver_1551', userId: 'dispatcher_9' });
}).add('no data', function () {
    return React.createElement(Messages, { conversationId: 'driver_1553', userId: 'dispatcher_9' });
}).add('custom no data message', function () {
    return React.createElement(Messages, {
        conversationId: 'driver_1553',
        userId: 'dispatcher_9',
        noDataMessage: React.createElement(
            'h3',
            { style: { textTransform: 'uppercase', textAlign: 'center' } },
            'Where are all my messges'
        )
    });
}).add('default loader', function () {
    return React.createElement(
        DataLoadDelay,
        { store: store, firebaseDataPath: 'messages/driver_1551' },
        React.createElement(Messages, { conversationId: 'driver_1551', userId: 'dispatcher_9' })
    );
}).add('custom loader', function () {
    return React.createElement(
        DataLoadDelay,
        {
            store: store,
            firebaseDataPath: 'messages/driver_1551'
        },
        React.createElement(Messages, {
            conversationId: 'driver_1551',
            userId: 'dispatcher_9',
            loader: React.createElement(
                'h3',
                { style: { color: 'blue', textAlign: 'center' } },
                'Loading messages with blue in heart'
            )
        })
    );
}).add('custom author', function () {
    return React.createElement(
        'div',
        { className: 'custom-author-messages' },
        React.createElement(Messages, {
            conversationId: 'driver_1551',
            userId: 'dispatcher_9',
            MessageAuthor: Author
        })
    );
}).add('custom message', function () {
    return React.createElement(
        'div',
        { className: 'custom-author-messages' },
        React.createElement(Messages, {
            conversationId: 'driver_1551',
            userId: 'dispatcher_9',
            MessageComponent: Message
        })
    );
}).add('disabled paging', function () {
    return React.createElement(
        'div',
        { className: 'custom-author-messages' },
        React.createElement(Messages, {
            conversationId: 'driver_1554',
            userId: 'dispatcher_9',
            MessageComponent: Message,
            disabledPaging: true
        })
    );
});