'use strict';

Object.defineProperty(exports, "__esModule", {
    value: true
});
exports.init = undefined;
exports.shallowWithIntl = shallowWithIntl;
exports.mountWithIntl = mountWithIntl;

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _reactIntl = require('react-intl');

var _reactRedux = require('react-redux');

var _reduxMockStore = require('redux-mock-store');

var _reduxMockStore2 = _interopRequireDefault(_reduxMockStore);

var _enzyme = require('enzyme');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var mockStore = (0, _reduxMockStore2.default)([]);

var state = void 0;
var intl = void 0;

var init = exports.init = function init() {
    var initialState = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
    var messages = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

    state = initialState;
    // Create the IntlProvider to retrieve context for wrapping around.
    var intlProvider = new _reactIntl.IntlProvider({ locale: 'cs', messages: messages }, {});
    intl = intlProvider.getChildContext().intl;
};

/**
 * When using React-Intl `injectIntl` on components, props.intl is required.
 */
function nodeWithIntlProp(node) {
    return _react2.default.createElement(_reactRedux.Provider, { store: mockStore(state) }, _react2.default.cloneElement(node, { intl: intl }));
}

function shallowWithIntl(node) {
    var _ref = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {},
        context = _ref.context;

    return (0, _enzyme.shallow)(nodeWithIntlProp(node), {
        context: Object.assign({}, context, { intl: intl })
    });
}

function mountWithIntl(node) {
    var _ref2 = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {},
        context = _ref2.context,
        childContextTypes = _ref2.childContextTypes;

    return (0, _enzyme.mount)(nodeWithIntlProp(node), {
        context: Object.assign({}, context, { intl: intl }),
        childContextTypes: Object.assign({}, { intl: _reactIntl.intlShape }, childContextTypes)
    });
}