'use strict';

Object.defineProperty(exports, "__esModule", {
    value: true
});

var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _typeof = typeof Symbol === "function" && typeof Symbol.iterator === "symbol" ? function (obj) { return typeof obj; } : function (obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; };

exports.runSagas = runSagas;
exports.runRouteDependencies = runRouteDependencies;
exports.runRouteActions = runRouteActions;
exports.routeRefresh = routeRefresh;

var _lodash = require('lodash');

var _lodash2 = _interopRequireDefault(_lodash);

var _pathToRegexp = require('path-to-regexp');

var _pathToRegexp2 = _interopRequireDefault(_pathToRegexp);

var _effects = require('redux-saga/effects');

var _selectors = require('../selectors');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var _marked = /*#__PURE__*/regeneratorRuntime.mark(tryCatch),
    _marked2 = /*#__PURE__*/regeneratorRuntime.mark(runSagas),
    _marked3 = /*#__PURE__*/regeneratorRuntime.mark(runRouteDependencies),
    _marked4 = /*#__PURE__*/regeneratorRuntime.mark(runRouteActions),
    _marked5 = /*#__PURE__*/regeneratorRuntime.mark(routeRefresh);

/**
 * Single saga runner, automatic try-catch with _COMPLETED, _SUCCEEDED, _FAILED event dispatches
 * @param type : String
 * @param saga : Generator
 * @returns {*} : Generator
 */
function tryCatch(type, saga) {
    var completed, succeeded, failed;
    return regeneratorRuntime.wrap(function tryCatch$(_context2) {
        while (1) {
            switch (_context2.prev = _context2.next) {
                case 0:
                    completed = function completed(action) {
                        return { type: action.type + '_COMPLETED' };
                    };

                    succeeded = function succeeded(action, result) {
                        return {
                            type: action.type + '_SUCCEEDED',
                            result: result
                        };
                    };

                    failed = function failed(action, error) {
                        return {
                            type: action.type + '_FAILED',
                            error: error
                        };
                    };

                    _context2.next = 5;
                    return (0, _effects.takeLatest)(type, /*#__PURE__*/regeneratorRuntime.mark(function invokeSaga() {
                        var action,
                            result,
                            _args = arguments;
                        return regeneratorRuntime.wrap(function invokeSaga$(_context) {
                            while (1) {
                                switch (_context.prev = _context.next) {
                                    case 0:
                                        action = _args.length <= 0 ? undefined : _args[0];
                                        _context.prev = 1;
                                        _context.next = 4;
                                        return saga.apply(undefined, _args);

                                    case 4:
                                        result = _context.sent;
                                        _context.next = 7;
                                        return (0, _effects.put)(succeeded(action, result));

                                    case 7:
                                        _context.next = 13;
                                        break;

                                    case 9:
                                        _context.prev = 9;
                                        _context.t0 = _context['catch'](1);
                                        _context.next = 13;
                                        return (0, _effects.put)(failed(action, _context.t0));

                                    case 13:
                                        _context.next = 15;
                                        return (0, _effects.put)(completed(action));

                                    case 15:
                                    case 'end':
                                        return _context.stop();
                                }
                            }
                        }, invokeSaga, this, [[1, 9]]);
                    }));

                case 5:
                    return _context2.abrupt('return', _context2.sent);

                case 6:
                case 'end':
                    return _context2.stop();
            }
        }
    }, _marked, this);
}

/**
 * Automatically invokes all given sagas for given event
 * Sagas: {[ActionType]: sagaHandler}
 * @param sagas : Object
 */
function runSagas(sagas) {
    var handlers, actionKeys, i, type, saga;
    return regeneratorRuntime.wrap(function runSagas$(_context3) {
        while (1) {
            switch (_context3.prev = _context3.next) {
                case 0:
                    handlers = [];
                    actionKeys = _lodash2.default.keys(sagas);

                    for (i = 0; i < actionKeys.length; i += 1) {
                        type = actionKeys[i];
                        saga = sagas[type];

                        handlers.push(tryCatch(type, saga));
                    }
                    _context3.next = 5;
                    return (0, _effects.all)(handlers);

                case 5:
                case 'end':
                    return _context3.stop();
            }
        }
    }, _marked2, this);
}

/**
 * Function that matches path to template and returns object of paramters if matched
 * @param path : String
 * @param template : String
 * @returns params : Object
 */
function matchPathToTemplate(path, template) {
    var keys = [];
    var params = (0, _pathToRegexp2.default)(template, keys).exec(path);
    var reducer = function reducer(res, x, i) {
        res[x.name] = params[i + 1];
        return res;
    };
    return params ? keys.reduce(reducer, {}) : null;
}

/**
 * Dependecies saga runner that runs sagaHandler for given route path if matches template
 * Sagas: {'template': sagaHandler}
 * @param sagas : Object
 * @param selector: (state: Object) => ({ pathname: String }: Object)
 */
function runRouteDependencies(handlers) {
    var selector = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : _selectors.routingSelector;
    var routing, pathname, handlersToRun, template, params;
    return regeneratorRuntime.wrap(function runRouteDependencies$(_context4) {
        while (1) {
            switch (_context4.prev = _context4.next) {
                case 0:
                    _context4.next = 2;
                    return (0, _effects.select)(selector);

                case 2:
                    routing = _context4.sent;
                    pathname = _lodash2.default.get(routing, 'pathname');

                    if (!(typeof pathname !== 'string')) {
                        _context4.next = 7;
                        break;
                    }

                    console.warn('Pathname is expected to be string but is ' + (typeof pathname === 'undefined' ? 'undefined' : _typeof(pathname)) + '\nThis is likely caused by custom selector you have passed via parameters.');
                    return _context4.abrupt('return');

                case 7:
                    handlersToRun = [];
                    // eslint-disable-next-line

                    for (template in handlers) {
                        params = matchPathToTemplate(pathname, template);

                        if (params) {
                            handlersToRun.push(handlers[template](params));
                        }
                    }
                    _context4.next = 11;
                    return (0, _effects.all)(handlersToRun);

                case 11:
                case 'end':
                    return _context4.stop();
            }
        }
    }, _marked3, this);
}

// Alias for runRouteDependecies
function runRouteActions(handlers, selector) {
    return regeneratorRuntime.wrap(function runRouteActions$(_context5) {
        while (1) {
            switch (_context5.prev = _context5.next) {
                case 0:
                    _context5.next = 2;
                    return runRouteDependencies(handlers, selector);

                case 2:
                case 'end':
                    return _context5.stop();
            }
        }
    }, _marked4, this);
}

/**
 * Saga to refresh route dependecies after action is done
 * @param {*} initType - intial action
 * @param {*} type - action to be dispatched into store
 * @param {*} handlers - viz. runRouteDependecies
 */
function routeRefresh(initType, type, handlers) {
    return regeneratorRuntime.wrap(function routeRefresh$(_context7) {
        while (1) {
            switch (_context7.prev = _context7.next) {
                case 0:
                    _context7.next = 2;
                    return (0, _effects.takeEvery)(initType, /*#__PURE__*/regeneratorRuntime.mark(function _callee(action) {
                        return regeneratorRuntime.wrap(function _callee$(_context6) {
                            while (1) {
                                switch (_context6.prev = _context6.next) {
                                    case 0:
                                        _context6.next = 2;
                                        return (0, _effects.put)(_extends({}, action, {
                                            type: type
                                        }));

                                    case 2:
                                        _context6.next = 4;
                                        return runRouteDependencies(handlers);

                                    case 4:
                                    case 'end':
                                        return _context6.stop();
                                }
                            }
                        }, _callee, this);
                    }));

                case 2:
                case 'end':
                    return _context7.stop();
            }
        }
    }, _marked5, this);
}