const path = require('path');
const Promise = require('bluebird');
const readdir = Promise.promisify(require('recursive-readdir'));
const fs = Promise.promisifyAll(require('fs'));

const docsPath = path.resolve(__dirname, '../docs');
const sourcesPath = path.resolve(__dirname, '../src');

const ignoreTestFiles = (file, stats) => stats.isDirectory() && file.indexOf('/__tests__') > -1;

const getSrcRelativePath = file => file.replace(sourcesPath, '');
const ignoreModules = (file, stats) => {
    const srcRelativePath = getSrcRelativePath(file);
    return stats.isDirectory() && srcRelativePath === '/modules';
};

const sourceFilesPatters = [
    ignoreTestFiles,
    ignoreModules,
    '.DS_Store',
    'index.js',
];

readdir(sourcesPath, sourceFilesPatters)
    .map(getSrcRelativePath)
    .filter(file => {
        return fs.accessAsync(path.join(docsPath, file).replace(/\.jsx?$/, '.md'))
            .then(() => false)
            .catch(() => true);
    })
    .then(files => {
        /* eslint-disable no-console */
        console.log('');
        console.log('There is potentially missing doc (or doc name differ from source file name) for:');
        console.log('');
        files.map(file => console.log('  ', file));
        console.log('');
        /* eslint-enable no-console */
    });
